# Generated by Django 4.0.1 on 2022-02-14 10:52

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0012_patient_orient'),
    ]

    operations = [
        migrations.AddField(
            model_name='food',
            name='dt',
            field=models.DateField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='medecines',
            name='dt',
            field=models.DateField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='used',
            name='dt',
            field=models.DateField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]



from datetime import datetime, date

from django import forms
from django.contrib.auth import get_user_model
from django.contrib.auth.forms import UserCreationForm
from django.contrib.auth.models import User
from django.db import transaction
from django.forms import ModelForm, ModelChoiceField, DateInput, TimeInput
from django.contrib.auth.models import User
from med import models
from django.urls import reverse

from django.contrib.auth.forms import UserCreationForm

User = get_user_model()


class CustomUserCreationForm(UserCreationForm, forms.Form):
    class Meta:
        model = User
        fields = ['username', 'password1', 'password2', 'email']

    def __init__(self, *args, **kwargs):
        super(CustomUserCreationForm, self).__init__(*args, **kwargs)
        self.fields['username'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'Entre Nom_Prenom...'})
        self.fields['password1'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'Enter password...'})
        self.fields['password2'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'Confirm password...'})

        self.fields['email'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'Email...'})




class addrdv(forms.Form):

    cass = [
        ('C', [
                ('Specialiste', 'Specialiste'),
                ('Generaliste', 'Generaliste'),
                ('Certeficat', 'Certeficat'),
                           ]),
        ('R', [
                ('1R', '1R'),
                ('2R', '2R'),
                ('3R', '3R'),
                           ]),
        ('P.CH', 'P.CH'),
        ('Lab', 'Lab'),
        ('Plat', 'Plat'),
        ('Av, An', 'Av, An'),
        ('ECG', 'ECG')


    ]
    hours = [
        ('8', '8'),
        ('9', '9'),
        ('10', '10'),
        ('11', '11'),
        ('12', '12'),
        ('13', '13'),
        ('14', '14'),
        ('15', '15'),
        ('16', '16')
    ]
    minutes = [
        ('00', '00'),
        ('15', '15'),
        ('30', '30'),
        ('45', '45'),

    ]

    Prestation = forms.CharField(widget=forms.Select(choices=cass))
    Comment = forms.CharField(required=False, widget=forms.TextInput(
        attrs={"class": "form-control", "placeholder": "Enter event comment"}))
    rdvtime = forms.DateTimeField(required=True,
                                  widget=DateInput(attrs={"type": "datetime-local", "class": "form-control"},
                                                   format="%Y-%m-%d"))
    paid = forms.DecimalField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Heur = forms.CharField(widget=forms.Select(choices=hours))
    Minute= forms.CharField(widget=forms.Select(choices=minutes))

class addts(forms.Form):
    hours = [
        ('8', '8'),
        ('9', '9'),
        ('10', '10'),
        ('11', '11'),
        ('12', '12'),
        ('13', '13'),
        ('14', '14'),
        ('15', '15'),
        ('16', '16')
    ]
    minutes = [
        ('00', '00'),
        ('15', '15'),
        ('30', '30'),
        ('45', '45'),

    ]
    H = forms.CharField(widget=forms.Select(choices=hours))
    M = forms.CharField(widget=forms.Select(choices=minutes))


class UserReg(forms.Form):
    status = [
        ('Confirme', 'Confirme'),
        ('Non conf', 'Non conf'),
        ('Present', 'Present'),
        ('Absent', 'Absent')


    ]
    cass = [
        ('-----', '-----'),
        (
         'C', [
            ('Specialiste', 'Specialiste'),
            ('Generaliste', 'Generaliste'),
            ('Certeficat', 'Certeficat'),
        ]),
        ('R', [
            ('1R', '1R'),
            ('2R', '2R'),
            ('3R', '3R'),
        ]),
        ('P.CH', [
            ('P.CH', 'P.CH'),
            ('Circusi', 'Circusi')

        ]),
        ('Lab', 'Lab'),
        ('Plat', 'Plat'),
        ('Av, An', 'Av, An'),
        ('ECG', 'ECG')

    ]
    hours = [
        ('8', '8'),
        ('9', '9'),
        ('10', '10'),
        ('11', '11'),
        ('12', '12'),
        ('13', '13'),
        ('14', '14'),
        ('15', '15'),
        ('16', '16')
    ]
    minutes = [
        ('00', '00'),
        ('15', '15'),
        ('30', '30'),
        ('45', '45'),

    ]
    Nom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prenom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Age = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Phone= forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Adresse = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))

    Commentaire = forms.CharField(required=False, widget=forms.TextInput(attrs={'class': 'form-control'}))
   # currentstate = forms.MultipleChoiceField(required=False, widget=forms.CheckboxSelectMultiple, choices=status)
    Cas = forms.CharField(widget=forms.Select(choices=status))

    #drid= forms.ChoiceField(widget=forms.CheckboxSelectMultiple(attrs={'class': 'form-select'}))
    #drid= forms.SelectMultiple(attrs={'class': 'form-control', 'placeholder': 'Attendees'})
   # drid= forms.Select(attrs={'class': 'form-select', 'placeholder': 'Venue'})
    Medcin= ModelChoiceField(queryset=models.Dctr.objects.all())

  #  drid= forms.SelectMultiple(attrs={'class': 'form-field', 'placeholder': 'Attendees'})
    #cas = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    """datereg = forms.DateTimeField(required=True, widget=forms.DateTimeField(attrs={'class': 'form-control'}))"""
    Prestation= forms.CharField(widget=forms.Select(choices=cass))
    Autre_Prestation_Si_Exist= forms.CharField(widget=forms.Select(choices=cass))
    rdvtime= forms.DateTimeField(required=True, widget= DateInput(  attrs={"type": "datetime-local", "class": "form-control"},  format="%Y-%m-%dT" ))
    Heur= forms.CharField(widget=forms.Select(choices=hours))
    Minute= forms.CharField(widget=forms.Select(choices=minutes))

    Prix = forms.FloatField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))


class AddOperatedPatient(forms.Form):
    status = [
        ('Confirme', 'Confirme'),
        ('Non conf', 'Non conf'),
        ('Present', 'Present'),
        ('Absent', 'Absent')
    ]
    cass = [
        (('-----', '-----'),
            'C', [

            ('Specialiste', 'Specialiste'),
            ('Generaliste', 'Generaliste'),
            ('Certeficat', 'Certeficat'),
        ]),
        ('R', [
            ('1R', '1R'),
            ('2R', '2R'),
            ('3R', '3R'),
        ]),
        ('P.CH', [
            ('P.CH', 'P.CH'),
            ('Circusi', 'Circusi')

        ]),
        ('Lab', 'Lab'),
        ('Plat', 'Plat'),
        ('Av, An', 'Av, An'),
        ('ECG', 'ECG')

    ]
    hours = [
        ('8', '8'),
        ('9', '9'),
        ('10', '10'),
        ('11', '11'),
        ('12', '12'),
        ('13', '13'),
        ('14', '14'),
        ('15', '15'),
        ('16', '16')
    ]
    minutes = [
        ('00', '00'),
        ('15', '15'),
        ('30', '30'),
        ('45', '45'),

    ]
    Nom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prenom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Age = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Phone= forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Adresse  = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))

    Commentaire = forms.CharField(required=False, widget=forms.TextInput(attrs={'class': 'form-control'}))
   # currentstate = forms.MultipleChoiceField(required=False, widget=forms.CheckboxSelectMultiple, choices=status)
    Cas = forms.CharField(widget=forms.Select(choices=status))

    #drid= forms.ChoiceField(widget=forms.CheckboxSelectMultiple(attrs={'class': 'form-select'}))
    #drid= forms.SelectMultiple(attrs={'class': 'form-control', 'placeholder': 'Attendees'})
   # drid= forms.Select(attrs={'class': 'form-select', 'placeholder': 'Venue'})
    Medcin= ModelChoiceField(queryset=models.Dctr.objects.all())

  #  drid= forms.SelectMultiple(attrs={'class': 'form-field', 'placeholder': 'Attendees'})
    #cas = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    """datereg = forms.DateTimeField(required=True, widget=forms.DateTimeField(attrs={'class': 'form-control'}))"""
    Date= forms.DateTimeField(required=True, widget= DateInput(  attrs={"type": "datetime-local", "class": "form-control"},  format="%Y-%m-%dT"))
    Heur= forms.CharField(widget=forms.Select(choices=hours))
    Minute= forms.CharField(widget=forms.Select(choices=minutes))
    Nature_Chirugie= forms.CharField(required=False, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Pix_propose= forms.FloatField( widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prix = forms.FloatField( widget=forms.TextInput(attrs={'class': 'form-control'}))
    Oriente = forms.CharField( widget=forms.TextInput(attrs={'class': 'form-control'}))
    Lit = forms.IntegerField( widget=forms.TextInput(attrs={'class': 'form-control'}))



class AddMedecines(forms.Form):
    types = [
        ('med1', 'med1'),
        ('med2', 'med2'),
        ('med3', 'med3'),
        ('med4', 'med4')

    ]
    Nom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Type= forms.CharField(widget=forms.Select(choices=types))
    Quantity = forms.IntegerField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prix = forms.FloatField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    class Meta:
        model = models.food
        fields = ['name', 'type', 'quantity', 'prix']


    @transaction.atomic
    def save(self):
        fd = models.medecines.objects.create()
        fd.name = self.cleaned_data.get('Nom')
        fd.type = self.cleaned_data.get('Type')
        fd.quantity = self.cleaned_data.get('Quantity')
        fd.prix = self.cleaned_data.get('Prix')
        fd.save()
        return fd


class AddFood(forms.Form):
    types = [
        ('des légumes ', 'des légumes '),
        ('des fruits', 'des fruits'),
        ('pain', 'pain'),
        ('eau', 'eau'),
        ('jus', 'jus'),
        (' lampes ', ' lampes '),
        ('gadgets', 'gadgets'),
        ('autres', 'autres'),

    ]
    Name = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Type= forms.CharField(widget=forms.Select(choices=types))
    Quantity = forms.IntegerField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prix = forms.FloatField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))

    class Meta:
        model = models.food
        fields = ['name', 'type', 'quantity', 'prix']


    @transaction.atomic
    def save(self):
        fd = models.food.objects.create()
        fd.name = self.cleaned_data.get('Name')
        fd.type = self.cleaned_data.get('Type')
        fd.quantity = self.cleaned_data.get('Quantity')
        fd.prix = self.cleaned_data.get('Prix')
        fd.save()
        return fd


class AddUsed(forms.Form):
    types = [
        ('Medicamentd ',  [
        ('med1', 'med1'),
        ('med2', 'med2'),
        ('med3', 'med3'),
        ('med4', 'med4')

    ]),

        ('aliments', [
        ('des légumes ', 'des légumes '),
        ('des fruits', 'des fruits'),
        ('pain', 'pain'),
        ('eau', 'eau'),
        ('jus', 'jus'),
        (' lampes ', ' lampes '),
        ('gadgets', 'gadgets'),


    ]),

        ('autre', 'autre')

    ]
    Name = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Type= forms.CharField(widget=forms.Select(choices=types))
    Quantity = forms.IntegerField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prix = forms.FloatField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))

    class Meta:
        model = models.Used
        fields = ['name', 'type', 'quantity', 'prix']


    @transaction.atomic
    def save(self):
        fuck = models.Used.objects.create()
        fuck.name = self.cleaned_data.get('Name')
        fuck.type = self.cleaned_data.get('Type')
        fuck.quantity = self.cleaned_data.get('Quantity')
        fuck.prix = self.cleaned_data.get('Prix')
        fuck.save()
        return fuck

class Recreg(UserCreationForm):
    Nom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prenom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Age = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Phone = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Adresse = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))

    class Meta(UserCreationForm.Meta):
        model = User

    @transaction.atomic
    def save(self):
        user = super().save(commit=False)
        user.is_admin = False
        user.is_receptionist = True
        user.fn = self.cleaned_data.get('Nom')
        user.ln = self.cleaned_data.get('Prenom')
        user.phone = self.cleaned_data.get('Phone')
        user.address = self.cleaned_data.get('Adresse')
        user.age = self.cleaned_data.get('Age')
        user.save()
        r = models.Rec.objects.create(user=user)
        r.save()
        return user

class Drreg(UserCreationForm):
    sectors = [
        ('A', 'A'),
        ('B', 'B'),
        ('C', 'C'),
        ('D', 'D'),
        ('E', 'E')

    ]

    Nom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prenom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Phone = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Speciality = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Poucentage = forms.CharField(required=False, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Poucentage_Chirurgie = forms.CharField(required=False, widget=forms.TextInput(attrs={'class': 'form-control'}))
    #payment = forms.CharField(required=False, widget=forms.TextInput(attrs={'class': 'form-control'}))
    """datereg = forms.DateTimeField(required=True, widget=forms.DateTimeField(attrs={'class': 'form-control'}))"""

    class Meta(UserCreationForm.Meta):
        model = User

    @transaction.atomic
    def save(self):
        user = super().save(commit=False)
        user.is_admin = False
        user.is_doctor = True
        user.fn = self.cleaned_data.get('Nom')
        user.ln = self.cleaned_data.get('Prenom')
        user.phone = self.cleaned_data.get('Phone')
        user.save()
        doctor = models.Dctr.objects.create(user=user)
        doctor.spec = self.cleaned_data.get('Speciality')
        doctor.prc=  self.cleaned_data.get('Poucentage')
        doctor.prccherg=  self.cleaned_data.get('Poucentage_Chirurgie')
        doctor.save()
        return user

class Assistant(UserCreationForm):

    Nom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Prenom = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Age = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Phone = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    Adresse = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    #role = forms.CharField(required=True, widget=forms.TextInput(attrs={'class': 'form-control'}))
    #role = forms.ChoiceField(required=False, widget=forms.CheckboxSelectMultiple, choices=roles)
    Medcin= ModelChoiceField(queryset=models.Dctr.objects.all())
    Medcin2= ModelChoiceField(queryset=models.Dctr.objects.all())
    Medcin3= ModelChoiceField(queryset=models.Dctr.objects.all())
    """datereg = forms.DateTimeField(required=True, widget=forms.DateTimeField(attrs={'class': 'form-control'}))"""

    class Meta(UserCreationForm.Meta):
        model = User

    @transaction.atomic
    def save(self):
        user = super().save(commit=False)
        user.is_admin = False
        user.is_assistant = True
        user.fn = self.cleaned_data.get('Prenom')
        user.ln = self.cleaned_data.get('Nom')
        user.phone = self.cleaned_data.get('Phone')
        user.address = self.cleaned_data.get('Adresse')
        user.age = self.cleaned_data.get('Age')
        user.save()
        assistant = models.Assistant.objects.create(user=user)
        assistant.drid.add(self.cleaned_data.get('Medcin'))
        assistant.drid.add(self.cleaned_data.get('Medcin2'))
        assistant.drid.add(self.cleaned_data.get('Medcin3'))
        assistant.save()
        return user

from .models import Patient, Dctr, Rdv


class PatForm(ModelForm):
    c = [
        ('Confirme', 'Confirme'),
        ('Non conf', 'Non conf'),
        ('Present', 'Present'),
        ('Absent', 'Absent')
    ]

    class Meta:
        model = Patient

        fields = ['prix', 'currentstate']

    def __init__(self, *args, **kwargs):
        super(PatForm, self).__init__(*args, **kwargs)
        self.fields['prix'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'Entre Nom_Prenom...'})
        self.fields['currentstate'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'Entre Nom_Prenom...'})






class updateRdv (forms.ModelForm):
    class Meta:
        model = Rdv

        fields = ['paid', 'rdvtime']

    def __init__(self, *args, **kwargs):
        super(updateRdv, self).__init__(*args, **kwargs)
        self.fields['paid'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'changer payment...'})
        self.fields['rdvtime'].widget.attrs.update(
            {'class': 'form-control', 'placeholder': 'date...'})


       # Rdv.save(update_fields=["paid"])





# Generated by Django 4.0.1 on 2022-02-17 21:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0016_patient_bed_alter_user_is_admin'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patient',
            name='bed',
            field=models.IntegerField(blank=True, default=0),
        ),
        migrations.AlterField(
            model_name='patient',
            name='orient',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AlterField(
            model_name='patient',
            name='prix',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=8),
        ),
        migrations.AlterField(
            model_name='patient',
            name='prixprop',
            field=models.DecimalField(blank=True, decimal_places=2, default=0, max_digits=8),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-06 23:54

from django.conf import settings
import django.contrib.auth.models
import django.contrib.auth.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=150, unique=True, validators=[django.contrib.auth.validators.UnicodeUsernameValidator()], verbose_name='username')),
                ('first_name', models.CharField(blank=True, max_length=150, verbose_name='first name')),
                ('last_name', models.CharField(blank=True, max_length=150, verbose_name='last name')),
                ('email', models.EmailField(blank=True, max_length=254, verbose_name='email address')),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('is_doctor', models.BooleanField(default=False)),
                ('is_admin', models.BooleanField(default=False)),
                ('is_assistant', models.BooleanField(default=False)),
                ('fn', models.CharField(default='', max_length=25)),
                ('ln', models.CharField(default='', max_length=25)),
                ('age', models.IntegerField(default=0)),
                ('phone', models.IntegerField(default=0)),
                ('address', models.CharField(default='', max_length=30)),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.Group', verbose_name='groups')),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions')),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
                'abstract': False,
            },
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='food',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=25)),
                ('type', models.CharField(default='', max_length=25)),
                ('quantity', models.IntegerField(default=1)),
                ('prix', models.FloatField(default=0)),
                ('total', models.FloatField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='medecines',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=25)),
                ('type', models.CharField(default='', max_length=25)),
                ('quantity', models.IntegerField(default=1)),
                ('prix', models.FloatField(default=0)),
                ('total', models.FloatField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='Patient',
            fields=[
                ('auto_increment_id', models.AutoField(primary_key=True, serialize=False)),
                ('firstname', models.CharField(default='', max_length=25)),
                ('lastname', models.CharField(default='', max_length=25)),
                ('age_patient', models.IntegerField(default=0)),
                ('phonep', models.IntegerField(default=0)),
                ('addressp', models.CharField(max_length=30)),
                ('currentstate', models.CharField(default='', max_length=10)),
                ('casp', models.CharField(default='', max_length=10)),
                ('cast', models.CharField(default='', max_length=10)),
                ('isin', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='TimeSlot',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('h', models.IntegerField()),
                ('m', models.CharField(max_length=2)),
            ],
        ),
        migrations.CreateModel(
            name='Dctr',
            fields=[
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to=settings.AUTH_USER_MODEL)),
                ('sector', models.CharField(default='', max_length=30)),
                ('spec', models.CharField(default='', max_length=25)),
                ('paymanet', models.FloatField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='Rdv',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('description', models.TextField()),
                ('paid', models.DecimalField(decimal_places=2, max_digits=8)),
                ('rdvtime', models.DateTimeField()),
                ('hr', models.IntegerField()),
                ('mn', models.CharField(max_length=2)),
                ('nature', models.CharField(default='', max_length=20)),
                ('prixprop', models.DecimalField(decimal_places=2, max_digits=8)),
                ('pp', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='med.patient')),
                ('dr', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='med.dctr')),
            ],
        ),
        migrations.AddField(
            model_name='patient',
            name='drid',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='med.dctr'),
        ),
        migrations.CreateModel(
            name='Assistant',
            fields=[
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to=settings.AUTH_USER_MODEL)),
                ('role', models.CharField(default='', max_length=25)),
                ('drid', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='med.dctr')),
            ],
        ),
    ]




from datetime import datetime, timedelta
from calendar import HTMLCalendar
from .models import Rdv

class Cal(HTMLCalendar):
	def __init__(self, year=None, month=None):
		self.year = year
		self.month = month
		super(Cal, self).__init__()

	# formats a day as a td
	# filter events by day
	def formatday(self, day, events):
		events_per_day = events.filter(rdvtime__day=day)
		d = ''
		for event in events_per_day:
			d += f'<li> {event.title} </li>'

		if day != 0:
			return f"<ul><span class='date'>{day}</span><li> {d} </li></ul>"
		return '<ul></ul>'

	# formats a week as a tr
	def formatweek(self, theweek, events):
		week = ''
		for d, weekday in theweek:
			week += self.formatday(d, events)
		return f'<ul> {week} </ul>'

	# formats a month as a table
	# filter events by year and month
	def formatmonth(self, withyear=True):
		events = Rdv.objects.filter(rdvtime__year=self.year, rdvtime__month=self.month)

		cal = f'\n'
		cal += f'{self.formatmonthname(self.year, self.month, withyear=withyear)}\n'
		cal += f'{self.formatweekheader()}\n'
		for week in self.monthdays2calendar(self.year, self.month):
			cal += f'{self.formatweek(week, events)}\n'
		return cal


import os
from datetime import timedelta
import datetime
import pytz

import httplib2
from googleapiclient.discovery import build
from oauth2client.service_account import ServiceAccountCredentials

service_account_email = 'XXX@YYY.iam.gserviceaccount.com'

CLIENT_SECRET_FILE = 'client_secret_441051712155-gqln6uffp29quehkdql4u6fmnha3jchc.apps.googleusercontent.com'

SCOPES = 'https://www.googleapis.com/auth/calendar'
scopes = [SCOPES]

def build_service():
    credentials = ServiceAccountCredentials.from_p12_keyfile(
        service_account_email=service_account_email,
        filename=CLIENT_SECRET_FILE,
        scopes=SCOPES
    )

    http = credentials.authorize(httplib2.Http())

    service = build('calendar', 'v3', http=http)

    return service


def create_event():
    service = build_service()

    start_datetime = datetime.datetime.now(tz=pytz.utc)
    event = service.events().insert(calendarId='<bechmanel@gmail.com', body={
        'summary': 'Foo',
        'description': 'Bar',
        'start': {'dateTime': start_datetime.isoformat()},
        'end': {'dateTime': (start_datetime + timedelta(minutes=15)).isoformat()},
    }).execute()

    print(event)


# Generated by Django 4.0.1 on 2022-02-09 22:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0005_rec_remove_assistant_role_user_is_receptionist_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='assistant',
            name='doctor',
            field=models.CharField(default='', max_length=30),
        ),
        migrations.AddField(
            model_name='assistant',
            name='dr',
            field=models.CharField(default='', max_length=30),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-10 20:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0007_remove_assistant_doctor_remove_assistant_dr_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='patient',
            name='prix',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=8),
        ),
    ]



import calendar

from django.contrib.auth.mixins import LoginRequiredMixin
from django.db.models import Sum, Count, OuterRef, Subquery
from django.shortcuts import render, redirect
from django.http import HttpResponse
# Create your views here.
from django.template.context_processors import csrf

from django.urls import reverse, reverse_lazy
from django.utils import timezone
from django.views.generic import CreateView, ListView
from django.http import HttpResponseRedirect
from med import models
from med import forms
from django.contrib.auth import login, logout, authenticate, get_user_model
from django.contrib.auth.forms import UserCreationForm, AuthenticationForm
from django.contrib.auth.decorators import login_required
from django.contrib import messages
from .forms import CustomUserCreationForm
from .models import Rdv
from datetime import timedelta, datetime, date
from django.views import generic
from django.utils.safestring import mark_safe

from .util import Cal
from .utils import Calendar
User = get_user_model()

def Index(request):
    context={'Nom': 'mags'}
    return render(request, 'index.html', context)




def chemin(request):
    patients = models.Patient.objects.all()

    context = {'p': patients}

    return render(request, 'chemin.html', context)


def floor(request):
    patients = models.Patient.objects.all()

    context = {'p': patients}

    return render(request, 'floor.html', context)


def op(request):
    patients = models.Patient.objects.all()

    context = {'p': patients}

    return render(request, 'op.html', context)
def PatientDetails(request, p):
    patients = models.Patient.objects.get(auto_increment_id=p)

    context = {'p': patients}

    return render(request, 'patientdetails.html', context)


def removeBed(request, p):
    pat = models.Patient.objects.get(auto_increment_id=p)
    pat.bed=0
    pat.save()
    return redirect('chemin')

    context = {'p': pat}

    return render(request, 'patientdetails.html', context)


@login_required(login_url='index')
def Patients( request):

    patients=models.Patient.objects.all()
    usr= request.user
   # rdv = models.Rdv.objects.filter(pp=d)
    doctor = models.Dctr
    a="Confirme"
    b="Non conf"
    c="Present"
    d="Absent"
    isin= False
    c1 = "Specialiste"
    c2 = "Generaliste"
    c3 = "Certeficat"
    r1 = "R1"
    r2 = "R2"
    r3 = "R3"
    fk='aa bb'

    context={'p': patients, 'dr':doctor, 'a':a, 'b':b, 'c':c, 'd':d, 'isin':isin,  'c1':c1,'c2':c2,'c3':c3, 'r1':r1,'r2':r2, 'r3':r3, 'usr':usr, 'fk':fk}
    return render(request, 'patient.html', context)
@login_required(login_url='index')

def PatientsOp( request):

    patients=models.Patient.objects.filter(isop=True)
   # rdv = models.Rdv.objects.filter(pp=d)
    doctor = models.Dctr
    a="Confirme"
    b="Non conf"
    c="Present"
    d="Absent"
    isin= False
    repeated= 0
    ori = models.Patient.objects.values('orient').annotate(Count('auto_increment_id')).filter(auto_increment_id__count__gt=3)
    orc= models.Patient.objects.filter(orient__in=[i['orient'] for i in ori])# <--- gt 0 will get all the objects having occurred in DB i.e is greater than 0
    for rep in orc:
        repeated=repeated+1
    subquery =  models.Patient.objects.filter(orient=OuterRef('orient')).values('orient').annotate(dup_count=Count('*'))
    rep=models.Patient.objects.all().annotate(dup_count=Subquery(subquery.values('orient')))
    context={'p': patients, 'dr':doctor, 'a':a, 'b':b, 'c':c, 'd':d, 'isin':isin, 'ori': orc, 'rep': rep}
    return render(request, 'oppatient.html', context)

@login_required(login_url='index')
def PatientsNonOp( request):

    patients=models.Patient.objects.filter(isop=False)
   # rdv = models.Rdv.objects.filter(pp=d)
    doctor = models.Dctr
    a="Confirme"
    b="Non conf"
    c="Present"
    d="Absent"
    e="  "

    isin= False
    context={'p': patients, 'dr':doctor, 'a':a, 'b':b, 'c':c, 'd':d, 'isin':isin, 'e':e }
    return render(request, 'patientm.html', context)

def isinn( request, p):
    ptt = models.Patient.objects.get(auto_increment_id=p)
    if ptt.isin == False:
        ptt.isin=True
    else:
        ptt.isin= False

    ptt.save()
    return redirect('patientm')
def isinnop( request, p):
    ptt = models.Patient.objects.get(auto_increment_id=p)
    if ptt.isin == False:
        ptt.isin=True
    else:
        ptt.isin= False

    ptt.save()
    return redirect('patientop')
def isinntout( request, p):
    ptt = models.Patient.objects.get(auto_increment_id=p)
    if ptt.isin == False:
        ptt.isin=True
    else:
        ptt.isin= False

    ptt.save()
    return redirect('patient')
def isinnts( request, p):
    ptt = models.Patient.objects.get(auto_increment_id=p)
    if ptt.isin == False:
        ptt.isin=True
    else:
        ptt.isin= False

    ptt.save()
    return redirect('ts')
@login_required(login_url='index')
def PatientsOfDoctor( request):
    user = request.user
    patients=models.Patient.objects.filter(drid=user.id)

    a = "Confirme"
    b = "Non conf"
    c = "Present"
    d = "Absent"
    isin = False
    c1 = "Specialiste"
    c2 = "Generaliste"
    c3 = "Certeficat"
    r1 = "R1"
    r2 = "R2"
    r3 = "R3"

    doctor = models.Dctr
    context={'p': patients, 'dr':doctor, 'a':a, 'b':b, 'c':c, 'd':d, 'isin':isin,  'c1':c1,'c2':c2,'c3':c3, 'r1':r1,'r2':r2, 'r3':r3}
    return render(request, 'drpatient.html', context)

@login_required(login_url='index')
def Medecines( request):

    meds=models.medecines.objects.all()
    food=models.food.objects.all()
    used=models.Used.objects.all()
    medtotal=0
    foodtotal=0
    usedtotal=0
    dt=date.today()


    for instance in food:
        instance.total= instance.prix * instance.quantity
    for t in meds:
        t.total= t.prix * t.quantity

    for mt in meds:
        medtotal += mt.total

    for ft in food:
        foodtotal += ft.total
    for s in used:
        s.total = s.prix * s.quantity

    for ss in used:
        usedtotal += ss.total





    context={'f': food, 'm': meds, 'mt':medtotal, 'ft':foodtotal, 'uu':used, 'ss':usedtotal, 'date':date.today()}
    #return HttpResponse('display all students here')
    return render(request, 'medecines.html', context)

@login_required(login_url='index')
def Food( request):

    fd=models.food.objects.all()


    context={'f': fd}
    #return HttpResponse('display all students here')
    return render(request, 'medecines.html', context)
def Used( request):

    fuck=models.Used.objects.all()


    context={'u': fuck}
    #return HttpResponse('display all students here')
    return render(request, 'medecines.html', context)
@login_required(login_url='index')
def Doctors( request):

    doctors=models.Dctr.objects.all()

    context={'d': doctors}
    #return HttpResponse('display all students here')
    return render(request, 'Drs.html', context)
@login_required(login_url='index')
def Assistants( request):

    assi=models.Assistant.objects.all()
    ass=models.Assistant
    dr=ass.drid




    context={'r': assi, 'dr':dr, 'm':assi}
    #return HttpResponse('display all students here')
    return render(request, 'assistants.html', context)
@login_required(login_url='index')
def Allrdvs( request):
    v = date.today()
    dt = v.day
    dm = v.month
    dy = v.year
    rdv=models.Rdv.objects.filter(rdvtime__day=dt, rdvtime__month=dm, rdvtime__year=dy)
    total = 0
    for instance in rdv:

        total += instance.paid
        print (total)

    context={'d': rdv, 'total':total}
    #return HttpResponse('display all students here')
    return render(request, 'allrdvs.html', context)
@login_required(login_url='index')
def MonthTotal( request):
    dt=date.today()
    mt=dt.month


    rdv=models.Rdv.objects.filter( rdvtime__month=mt)
    total = 0
    for instance in rdv:

        total += instance.paid
        print (total)

    context={'d': rdv, 'total':total}
    #return HttpResponse('display all students here')
    return render(request, 'monthtotal.html', context)
@login_required(login_url='index')
def YearTotal( request):
    dt=date.today()
    mt=dt.year


    rdv=models.Rdv.objects.filter( rdvtime__year=mt)
    total = 0
    for instance in rdv:

        total += instance.paid
        print (total)

    context={'d': rdv, 'total':total}
    #return HttpResponse('display all students here')
    return render(request, 'yeartotal.html', context)
@login_required(login_url='index')
def WeekTotal( request):
    dt=date.today()
    end_date = dt - timedelta(days=7)


    rdv=models.Rdv.objects.filter( rdvtime__range=(end_date, dt))
    total = 0
    for instance in rdv:

        total += instance.paid
        print (total)

    context={'d': rdv, 'total':total}
    #return HttpResponse('display all students here')
    return render(request, 'weektotal.html', context)
@login_required(login_url='index')
def DailyIncome(request, did):
    dt=datetime.today()
    v = date.today()
    dt = v.day
    dm = v.month
    dy = v.year
    yesterday = datetime.today() - timedelta(days=1)
    rdv = models.Rdv.objects.filter(dr=did, rdvtime__day=dt, rdvtime__month=dm, rdvtime__year=dy)
    total = 0
    for instance in rdv:
        total += instance.paid
        print(total)

    context = {'dd': rdv, 'total': total, 'did': did, 'y':yesterday}
    # return HttpResponse('display all students here')
    return render(request, 'drrdv.html', context)
@login_required(login_url='index')
def WeeklyIncome(request, did):

    v = date.today()
    end_date = v - timedelta(days=7)

    yesterday = datetime.today() - timedelta(days=1)
    rdv = models.Rdv.objects.filter(dr=did, rdvtime__range=(end_date, v))
    total = 0
    for instance in rdv:
        total += instance.paid
        print(total)

    context = {'dd': rdv, 'total': total, 'did': did, 'y':yesterday}
    # return HttpResponse('display all students here')
    return render(request, 'weeklyincome.html', context)
@login_required(login_url='index')
def DailyDr(request):
    dt=datetime.today()
    usr=request.user
    v = date.today()
    dt = v.day
    dm = v.month
    dy = v.year
    yesterday = datetime.today() - timedelta(days=1)
    rdv = models.Rdv.objects.filter(dr=usr.id, rdvtime__day=dt, rdvtime__month=dm, rdvtime__year=dy)
    total = 0
    for instance in rdv:
        total += instance.paid
        print(total)

    context = {'dd': rdv, 'total': total, 'did': usr, 'y':yesterday}
    # return HttpResponse('display all students here')
    return render(request, 'drrdv.html', context)
@login_required(login_url='index')
def WeeklyDr(request):
    usr=request.user
    v = date.today()
    end_date = v - timedelta(days=7)

    yesterday = datetime.today() - timedelta(days=1)
    rdv = models.Rdv.objects.filter(dr=usr.id, rdvtime__range=(end_date, v))
    total = 0
    for instance in rdv:
        total += instance.paid
        print(total)

    context = {'dd': rdv, 'total': total, 'did': usr, 'y':yesterday}
    # return HttpResponse('display all students here')
    return render(request, 'weeklyincome.html', context)
@login_required(login_url='loginmed')
def MonthIncome( request, did):
    v = date.today()
    dt = v.month
    rdv = models.Rdv.objects.filter(dr=did, rdvtime__month=dt)
    total = 0
    for n in rdv:
        total += n.paid
    context={'dd': rdv, 'total':total, 'did':did, 'dt': dt}
    #return HttpResponse('display all students here')
    return render(request, 'monthincome.html', context)
@login_required(login_url='loginmed')
def MonthDr( request):
    v = date.today()
    usr=request.user
    dt = v.month
    rdv = models.Rdv.objects.filter(dr=usr.id, rdvtime__month=dt)
    total = 0
    for n in rdv:
        total += n.paid
    context={'dd': rdv, 'total':total, 'did':usr, 'dt': dt}
    #return HttpResponse('display all students here')
    return render(request, 'monthincome.html', context)
@login_required(login_url='login')
def YearIncome( request, did):
    v = date.today()

    dt = v.year
    rdv = models.Rdv.objects.filter(dr=did, rdvtime__year=dt)
    drr=models.Dctr.objects.filter(user_id=did)
    total = 0
    for n in rdv:
        total += n.paid
    context={'dd': rdv, 'total':total, 'did':did, 'dt': dt, 'drr':drr}
    #return HttpResponse('display all students here')
    return render(request, 'yearincome.html', context)

@login_required(login_url='index')
def YearDr( request):
    v = date.today()
    usr=request.user

    dt = v.year
    rdv = models.Rdv.objects.filter(dr=usr.id, rdvtime__year=dt)
    #drr=models.Dctr.objects.filter(user_id=did)
    total = 0
    for n in rdv:
        total += n.paid
    context={'dd': rdv, 'total':total, 'did':usr, 'dt': dt}
    #return HttpResponse('display all students here')
    return render(request, 'yearincome.html', context)
@login_required(login_url='index')

def test(request):
    return render(request, 'test.html')

def Register(request):
    fd=forms.UserReg(request.POST or None)
    dt=date.today()

    msg = ''
    if fd.is_valid():
        pt= models.Patient()

       # r=models.Event(pp=pt.objects.get(auto_increment_id=pt.auto_increment_id))
        r=models.Rdv()
        pt.firstname = fd.cleaned_data['Prenom']
        pt.lastname = fd.cleaned_data['Nom']
        pt.age_patient = fd.cleaned_data['Age']
        pt.phonep = fd.cleaned_data['Phone']
        pt.addressp = fd.cleaned_data['Adresse']
        r.pp=pt
        pt.drid = fd.cleaned_data['Medcin']
        pt.currentstate = fd.cleaned_data['Cas']
        pt.casp=fd.cleaned_data['Prestation']
        pt.cast=fd.cleaned_data['Autre_Prestation_Si_Exist']
        pt.prix=fd.cleaned_data['Prix']
        r.title= fd.cleaned_data['Prestation']
        r.rdvtime= fd.cleaned_data['rdvtime']
        r.hr = fd.cleaned_data['Heur']
        r.mn = fd.cleaned_data['Minute']
        r.paid = fd.cleaned_data['Prix']

        r.dr=pt.drid


       # pt.rdv.title = fd.cleaned_data['cas']

        pt.save()
        r.save()

        msg = 'data is saved'
        return redirect('patient')

    context = {'formreg': fd,

               'msg': msg
    }

    return render(request, 'register.html', context)


def draddpat(request):
    fd = forms.UserReg(request.POST or None)
    dt = date.today()

    msg = ''
    if fd.is_valid():
        pt = models.Patient()

        # r=models.Event(pp=pt.objects.get(auto_increment_id=pt.auto_increment_id))
        r = models.Rdv()
        pt.firstname = fd.cleaned_data['First_Name']
        pt.lastname = fd.cleaned_data['Last_Name']
        pt.age_patient = fd.cleaned_data['Age']
        pt.phonep = fd.cleaned_data['Phone']
        pt.addressp = fd.cleaned_data['Address']
        r.pp = pt
        pt.drid = fd.cleaned_data['doctor']
        pt.currentstate = fd.cleaned_data['currentstate']
        pt.casp = fd.cleaned_data['Prestation']
        pt.cast = fd.cleaned_data['Autre_Prestation_Si_Exist']
        pt.prix = fd.cleaned_data['Prix']
        r.title = fd.cleaned_data['Prestation']
        r.rdvtime = fd.cleaned_data['rdvtime']
        r.hr = fd.cleaned_data['Heur']
        r.mn = fd.cleaned_data['Minute']
        r.paid = fd.cleaned_data['Prix']

        r.dr = pt.drid

        # pt.rdv.title = fd.cleaned_data['cas']

        pt.save()
        r.save()

        msg = 'data is saved'
        return redirect('pd')

    context = {'formreg': fd,

               'msg': msg
               }

    return render(request, 'draddpat.html', context)
def AjoutPatOp(request):
    fd=forms.AddOperatedPatient(request.POST or None)
    dt=date.today()

    msg = ''
    if fd.is_valid():
        pt= models.Patient()

       # r=models.Event(pp=pt.objects.get(auto_increment_id=pt.auto_increment_id))
        r=models.Rdv()
        pt.isop=True
        pt.firstname = fd.cleaned_data['Prenom']
        pt.lastname = fd.cleaned_data['Nom']
        pt.age_patient = fd.cleaned_data['Age']
        pt.phonep = fd.cleaned_data['Phone']
        pt.addressp = fd.cleaned_data['Adresse']
        r.pp=pt
        pt.drid = fd.cleaned_data['Medcin']
        pt.currentstate = fd.cleaned_data['Cas']
        pt.nature=fd.cleaned_data['Nature_Chirugie']
        pt.prixprop=fd.cleaned_data['Pix_propose']
        pt.prix=fd.cleaned_data['Prix']
        pt.orient=fd.cleaned_data['Oriente']
        pt.bed=fd.cleaned_data['Lit']

        pt.casp="Cherigie"
        r.rdvtime= fd.cleaned_data['Date']
        r.hr = fd.cleaned_data['Heur']
        r.mn = fd.cleaned_data['Minute']
        r.paid = fd.cleaned_data['Prix']
      #  r.prixprop = fd.cleaned_data[' Pix_propose']
       # r.nature = fd.cleaned_data[' Nature_Chirugie']
        r.dr=pt.drid
       # pt.rdv.title = fd.cleaned_data['cas']

        pt.save()
        r.save()

        msg = 'data is saved'
        return redirect('ts')

    context = {'formreg': fd,

               'msg': msg
    }
    return render(request, 'ajoutpatop.html', context)
@login_required(login_url='index')


def DrAjoutPatOp(request):
    fd=forms.AddOperatedPatient(request.POST or None)
    dt=date.today()

    msg = ''
    if fd.is_valid():
        pt= models.Patient()

       # r=models.Event(pp=pt.objects.get(auto_increment_id=pt.auto_increment_id))
        r=models.Rdv()
        pt.isop=True
        pt.firstname = fd.cleaned_data['Prenom']
        pt.lastname = fd.cleaned_data['Nom']
        pt.age_patient = fd.cleaned_data['Age']
        pt.phonep = fd.cleaned_data['Phone']
        pt.addressp = fd.cleaned_data['Adresse']
        r.pp=pt
        pt.drid = fd.cleaned_data['Medcin']
        pt.currentstate = fd.cleaned_data['Cas']
        pt.nature=fd.cleaned_data['Nature_Chirugie']
        pt.prixprop=fd.cleaned_data['Pix_propose']
        pt.prix=fd.cleaned_data['Prix']
        pt.orient=fd.cleaned_data['Oriente']
        pt.bed=fd.cleaned_data['Lit']

        pt.casp="Cherigie"
        r.rdvtime= fd.cleaned_data['Date']
        r.hr = fd.cleaned_data['Heur']
        r.mn = fd.cleaned_data['Minute']
        r.paid = fd.cleaned_data['Prix']
      #  r.prixprop = fd.cleaned_data[' Pix_propose']
       # r.nature = fd.cleaned_data[' Nature_Chirugie']
        r.dr=pt.drid
       # pt.rdv.title = fd.cleaned_data['cas']

        pt.save()
        r.save()

        msg = 'data is saved'
        return redirect('pd')

    context = {'formreg': fd,

               'msg': msg
    }
    return render(request, 'draddpatp.html', context)
@login_required(login_url='index')



def AddRdv (request, pk):
    fd = forms.addrdv(request.POST or None)
    ptt = models.Patient.objects.get(auto_increment_id=pk)
    dt = date.today()

    if fd.is_valid():
         # r=models.Event(pp=pt.objects.get(auto_increment_id=pt.auto_increment_id))
        r = models.Rdv()
        r.title = fd.cleaned_data['Prestation']
        r.description = fd.cleaned_data['Commentaire']
        r.rdvtime = fd.cleaned_data['rdvtime']

        r.hr=fd.cleaned_data['Heur']
        r.mn=fd.cleaned_data['Minute']
        r.paid = fd.cleaned_data['Prix']

        r.dr=ptt.drid

        r.pp = ptt
        r.save()
        return redirect('allrdvs')

    context = {'formi': fd }
    return render(request, 'addrdv.html', context)

@login_required(login_url='index')

def AddTime (request):

    fd = forms.addts(request.POST or None)
    if fd.is_valid():
        ts = models.TimeSlot()
        ts.h = fd.cleaned_data['H']
        ts.m = fd.cleaned_data['M']
        ts.save()
    v = date.today()
    es="     "
    dt = v.day
    dm = v.month
    dy = v.year
    tss = models.TimeSlot.objects.all()
    dd = models.Dctr.objects.all()
    dc=''


    a = "Confirme"
    b = "Non conf"
    c = "Present"
    d = "Absent"

    dv=models.Rdv.objects.all()
   # dv=models.Rdv.objects.filter(rdvtime__day=dt, rdvtime__month=dm, rdvtime__year=dy )
    for hal in dv:
        {'fff': hal}

    context = {'formi': fd, 'ts':tss , 'd':dd, 'v':v, 'dv':dv, 'a':a, 'b':b, 'c':c, 't':d, 'es':es,  "data" : [dd]}
    return render(request, 'timeslot.html', context)

@login_required(login_url='index')

@login_required(login_url='index')
def TimeSlotDoctor (request):

    fd = forms.addts(request.POST or None)
    usr=request.user
    if fd.is_valid():
        ts = models.TimeSlot()
        ts.h = fd.cleaned_data['H']
        ts.m = fd.cleaned_data['M']
        ts.save()
    v = date.today()
    dt = v.day
    dm = v.month
    dy = v.year
    tss = models.TimeSlot.objects.all()
    dd = models.Dctr.objects.get( user_id=usr.id)
    a = "Confirme"
    b = "Non conf"
    c = "Present"
    d = "Absent"
    #dv=models.Rdv.objects.filter(dr=usr.id)
    dv=models.Rdv.objects.filter(rdvtime__day=dt, rdvtime__month=dm, rdvtime__year=dy)
    for hal in dv:
        {'fff': hal}

    context = {'formi': fd, 'ts':tss , 'd':dd, 'v':v, 'dv':dv, 'a':a, 'b':b, 'c':c, 't':d}
    return render(request, 'timeslotdr.html', context)

@login_required(login_url='index')

def TimeSlotAssistsnt (request):

    fd = forms.addts(request.POST or None)
    usr=request.user
    ass=models.Assistant.objects.get(user_id=usr)

    if fd.is_valid():
        ts = models.TimeSlot()
        ts.h = fd.cleaned_data['H']
        ts.m = fd.cleaned_data['M']
        ts.save()

    bbb=ass.drid
    v = date.today()
    dt = v.day
    dm = v.month
    dy = v.year
    tss = models.TimeSlot.objects.all()
    dd = models.Dctr.objects.all()
    a = "Confirme"
    b = "Non conf"
    c = "Present"
    d = "Absent"
    dv=models.Rdv.objects.all()
   # dv=models.Rdv.objects.filter(rdvtime__day=dt, rdvtime__month=dm, rdvtime__year=dy )


    context = {'formi': fd, 'ts':tss , 'd':dd, 'v':v, 'dv':dv, 'a':a, 'b':b, 'c':c, 't':d, 'bbb':bbb, 'ass':ass}
    return render(request, 'assistant.html', context)

@login_required(login_url='index')

def AddMed (request):
    form = forms.AddMedecines()
    if request.method == 'POST':
        form = forms.AddMedecines(request.POST)
        if form.is_valid():
            food = form.save()
            food.save()
            return redirect('medecines')

    context = {'form': form}
    return render(request, 'addmed.html', context)


@login_required(login_url='index')

def Addfood (request):
     form = forms.AddFood()
     if request.method == 'POST':
         form = forms.AddFood(request.POST)
         if form.is_valid():
             food = form.save()
             food.save()
             return redirect('medecines')


     context = {'form': form}
     return render(request, 'addfood.html', context)


@login_required(login_url='index')

def AddUsed (request):
     form = forms.AddUsed()
     if request.method == 'POST':
         form = forms.AddUsed(request.POST)
         if form.is_valid():
             usd = form.save()
             usd.save()
             return redirect('medecines')


     context = {'form': form}
     return render(request, 'addused.html', context)


'''''

def create_event(request):
    form = EventForm(request.POST or None)
    if request.POST and form.is_valid():
        title = form.cleaned_data["title"]
        description = form.cleaned_data["description"]
        start_time = form.cleaned_data["start_time"]
        Event.objects.get_or_create(
            user=request.user,
            title=title,
            description=description,
            start_time=start_time,
        )
        #return HttpResponseRedirect(reverse("calendar"))
    return render(request, "register.html", {"form": form})
    '''

def loginUser(request):
    page = 'login'
    if request.method == 'POST':



        username = request.POST['username']
        password = request.POST['password']

        user = authenticate(request, username=username, password=password)

        if user is not None:
            if user.is_doctor== False and user.is_assistant == False:
                login(request, user)
                return redirect('patient')


    return render(request, 'login.html', {'page': page})


def logoutUser(request):
    logout(request)
    return redirect('index')


def addadmin(request):


    form = CustomUserCreationForm()
    models.User.is_doctor == False
    models.User.is_assistant == False
    models.User.is_admin == True

    if request.method == 'POST':
        models.User.is_admin == True
        form = CustomUserCreationForm(request.POST)
        if form.is_valid():
            models.User.is_admin == True
            user = form.save(commit=False)
            user.save()

            if user is not None:
                login(request, user)
                return redirect('patient')

    context = {'form': form}
    return render(request, 'addadmin.html', context)

def registerUser(request):
    page = 'reg'

    form = CustomUserCreationForm()

    if request.method == 'POST':
        form = CustomUserCreationForm(request.POST)
        if form.is_valid():
            user = form.save(commit=False)
            user.save()

            if user is not None:
                login(request, user)
                return redirect('patient')

    context = {'form': form, 'page': page}
    return render(request, 'login.html', context)


def search(request):


    if request.method == "POST":

        searched = request.POST['searched']

        pts = models.Patient.objects.filter(lastname=searched)

        return render(request, 'search.html', {'searched': searched, 'pts': pts})
    else:
        return render(request, 'search.html')


def drsearch(request):
    usr = request.user
    if request.method == "POST":

        searched = request.POST['searched']
        pts = models.Patient.objects.filter(lastname=searched, drid=usr.id)

        return render(request, 'drsearch.html', {'searched': searched, 'pts': pts})
    else:
        return render(request, 'drsearch.html')
@login_required(login_url='index')
def deletePatient(request, pk):
	order = models.Patient.objects.get(auto_increment_id=pk)
	if request.method == "POST":
		order.delete()
		return redirect('patient')

	context = {'item':order}
	return render(request, 'delete.html', context)
@login_required(login_url='index')
def updatePatient(request, pk):

	pp = models.Patient.objects.get(auto_increment_id=pk)

	form = forms.PatForm(instance=pp)

	if request.method == 'POST':
		form = forms.PatForm(request.POST, instance=pp)

		if form.is_valid():
			form.save()

			return redirect('patient')

	context = {'form':form, 'pp':pp}
	return render(request, 'test.html', context)




def updateRdv(request, p):
    rd = models.Rdv.objects.get(id=p)
    f = forms.updateRdv(instance=rd)

    if request.method == 'POST':
        f = forms.updateRdv(request.POST, instance=rd)

        if f.is_valid():
            f.save()
            return redirect('patient')


    context = {'f': f, 'ss':rd}
    return render(request, 'updaterdv.html', context)

    """""
    if request.method == 'POST':
        t.paid = request.POST["po"]

        t.save(update_fields=["paid"])
    context={'ff':f}
    return render(request, 'rdvs.html', context)
    """

@login_required(login_url='index')

def deleteDoctor(request, pk):
	dr = models.Dctr.objects.get(user_id=pk)
	if request.method == "POST":
		dr.delete()
		return redirect('Drs')

	context = {'item':dr}
	return render(request, 'deletedr.html', context)

def deleteAssistant(request, pk):
	dr = models.Assistant.objects.get(user_id=pk)
	if request.method == "POST":
		dr.delete()
		return redirect('assistants')

	context = {'item':dr}
	return render(request, 'deleteass.html', context)

@login_required(login_url='index')

def deleteRdv(request, pk):
	rdv = models.Rdv.objects.get(id=pk)
	if request.method == "POST":
		rdv.delete()

	context = {'item':rdv}
	return render(request, 'rdvs.html', context)

def deletets(request, pk):
	rdv = models.TimeSlot.objects.get(id=pk)
	if request.method == "POST":
		rdv.delete()


	context = {'item':rdv}
	return render(request, 'timeslot.html', context)


def deleteMed(request, pk):
	mmmm = models.medecines.objects.get(id=pk)
	if request.method == "POST":
	    mmmm.delete()

	return redirect('medecines')
def deleteFood(request, p):
	foods = models.food.objects.get(id=p)
	if request.method == "POST":
		foods.delete()


	return redirect('medecines')

def deleteUsed(request, p):
	foods = models.food.objects.get(id=p)
	if request.method == "POST":
		foods.delete()


	return redirect('medecines')
def login_view(request):
    form = forms.LoginForm(request.POST or None)
    msg = None
    if request.method == 'POST':
        if models.user.is_assistant==True :

            if form.is_valid():
                username = form.cleaned_data.get('username')
                password = form.cleaned_data.get('password')
                user = authenticate(username=username, password=password)
                if user is not None and user.is_admin:
                    login(request, user)
                    return redirect('drreg')
                elif user is not None and user.is_customer:
                    login(request, user)
                    return redirect('patient')

                else:
                    msg= 'invalid credentials'
            else:
                msg = 'error validating form'
        else:
            msg = 'Utilisateur peut etre pas assistant'
    return render(request, 'loginass.html', {'form': form, 'msg': msg})


class doctor_register(CreateView):

    model = models.User
    form_class = forms.Drreg
    template_name = '../templates/drreg.html'

    def form_valid(self, form):
        user = form.save()
        login(self.request, user)
        return redirect('Drs')

class reciptionist_register(CreateView):

    model = models.User
    form_class = forms.Recreg
    template_name = '../templates/addrec.html'

    def form_valid(self, form):
        user = form.save()
        login(self.request, user)
        return redirect('ts')

class assistant_register(CreateView):
    msg=' '
    model = models.User
    form_class = forms.Assistant
    template_name = '../templates/assreg.html'

    def form_valid(self, form):
        user = form.save()
        login(self.request, user)
        return redirect('assistants')

class draddass(CreateView):
    msg=' '
    model = models.User
    form_class = forms.Assistant
    template_name = '../templates/assreg.html'

    def form_valid(self, form):
        user = form.save()
        login(self.request, user)
        return redirect('pd')

def getrdv(request, pk):
    #rdv = models.Event.objects.filter(pp=p)

    p = models.Patient.objects.get(auto_increment_id=pk)
    rdv = models.Rdv.objects.filter(pp=p)
    rd = models.Rdv.objects.all()



    context = {'rdv': rdv, 'ppp':p, 'rd':rd}

    return render(request, 'rdvs.html', context)

def login_request(request):


    if request.method=='POST':
        form = AuthenticationForm(data=request.POST)

        if form.is_valid():
            username = form.cleaned_data.get('username')
            password = form.cleaned_data.get('password')
            user = authenticate(username=username, password=password)
            if user is not None :
                if user.is_doctor == True:
                    login(request,user)
                    return redirect('pd')
                else:
                    messages.error(request, "User is not Doctor")


            else:
                messages.error(request,"Invalid username or password")
        else:
                messages.error(request,"Invalid username or password")

    return render(request, '../templates/loginmed.html',
    context={'form':AuthenticationForm()})
def login_ass(request):


    if request.method=='POST':
        form = AuthenticationForm(data=request.POST)

        if form.is_valid():
            username = form.cleaned_data.get('username')
            password = form.cleaned_data.get('password')
            user = authenticate(username=username, password=password)
            if user is not None :

                if user.is_assistant == True:
                    login(request, user)
                    return redirect('tsa')
                else:
                    messages.error(request, "User is not Assistant")



            else:
                messages.error(request,"Invalid username or password")
        else:
                messages.error(request,"Invalid username or password")

    return render(request, '../templates/loginass.html',
    context={'form':AuthenticationForm()})

def login_rec(request):


    if request.method=='POST':
        form = AuthenticationForm(data=request.POST)

        if form.is_valid():
            username = form.cleaned_data.get('username')
            password = form.cleaned_data.get('password')
            user = authenticate(username=username, password=password)
            if user is not None :

                if user.is_receptionist == True:
                    login(request, user)
                    return redirect('ts')
                else:
                    messages.error(request, "User is not Receptionist")



            else:
                messages.error(request,"Invalid username or password")
        else:
                messages.error(request,"Invalid username or password")

    return render(request, '../templates/loginrec.html',
    context={'form':AuthenticationForm()})
def logout_view(request):
    logout(request)
    return redirect('/')


class CalendarView(generic.ListView):
    model = Rdv
    template_name = 'calendar.html'

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)

        # use today's date for the calendar
        d = get_date(self.request.GET.get('day', None))
        m = get_date(self.request.GET.get('month', None))
        context['prev_month'] = prev_month(m)
        context['next_month'] = next_month(m)



        # Instantiate our calendar class with today's year and date
        cal = Calendar(m.year, m.month)

        # Call the formatmonth method, which returns our calendar as a table
        html_cal = cal.formatmonth(withyear=True)
        context['calendar'] = mark_safe(html_cal)
        dt = date.today()
        mt = dt.month

        rdv = models.Rdv.objects.filter( rdvtime__month=m.month)
        total = 0
        for instance in rdv:
            total += instance.paid
            print(total)
        context['d'] = rdv
        context['total'] = total
        # return HttpResponse('display all students here')


        return context



def get_date(req_day):
    if req_day:
        year, month = (int(x) for x in req_day.split('-'))
        return date(year, month, day=1)
    return datetime.today()


def prev_month(m):
    first = m.replace(day=1)
    prev_month = first - timedelta(days=1)
    month = 'month=' + str(prev_month.year) + '-' + str(prev_month.month)
    return month

def next_month(m):
    days_in_month = calendar.monthrange(m.year, m.month)[1]
    last = m.replace(day=days_in_month)
    next_month = last + timedelta(days=1)
    month = 'month=' + str(next_month.year) + '-' + str(next_month.month)
    return month




# Generated by Django 4.0.1 on 2022-02-10 21:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0008_patient_prix'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='age',
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-16 20:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0015_alter_patient_currentstate'),
    ]

    operations = [
        migrations.AddField(
            model_name='patient',
            name='bed',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='user',
            name='is_admin',
            field=models.BooleanField(default=True),
        ),
    ]



"""medapp URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
#from django.conf.urls import url
from med.views import Index, updateRdv, DailyIncome, MonthIncome, YearIncome, MonthTotal, CalendarView, YearTotal, \
    AddTime, deletets, isinn, AjoutPatOp, AddUsed, deleteUsed, Used, PatientsOp, PatientsNonOp, login_view, isinnop, \
    isinntout, PatientsOfDoctor, reciptionist_register, login_ass, login_rec, DailyDr, MonthDr, YearDr, TimeSlotDoctor, \
    isinnts, TimeSlotAssistsnt, Assistants, WeekTotal, WeeklyIncome, WeeklyDr, chemin, PatientDetails, floor, op, \
    removeBed, draddpat, DrAjoutPatOp, deleteAssistant, drsearch, draddass

from med.views import Patients,  deleteDoctor,  addadmin, AddMed, Addfood, Medecines, Food, getrdv, Allrdvs, deleteRdv, deleteMed, deleteFood, AddRdv
#from med.views import CalendarView, AllEventsListView, EventEdit, RunningEventsListView,
from med.views import Doctors
from med.views import Register, test, loginUser, logoutUser, registerUser, deletePatient, updatePatient, search, doctor_register, login_request, assistant_register, Doctors

urlpatterns = [
    path('admin/', admin.site.urls),
    path('',Index, name='index'),
    path('patient/',Patients, name='patient'),
    path('patientop/',PatientsOp, name='patientop'),
    path('patientm/',PatientsNonOp, name='patientm'),
    path('doctor/',Doctors, name='doctor'),
    path('register/',Register, name='register'),
    path('test/',test, name='test'),
    path('login/',loginUser, name='login'),
    path('loginass/',login_ass, name='loginass'),
    path('logout/',logoutUser, name='logout'),
    path('delete/<str:pk>/',deletePatient, name='delete'),
    path('deleteRdv/<str:pk>/',deleteRdv, name='deleteRdv'),
    path('deleteFood/<str:p>/',deleteFood, name='deleteFood'),
    path('deleteMed/<str:pk>/',deleteMed, name='deleteMed'),
    path('deleteused/<str:pk>/',deleteUsed, name='deleteused'),
    path('deleteass/<str:pk>/',deleteAssistant, name='deleteass'),
    path('updaterdv/<str:p>/',updateRdv, name='updaterdv'),
    path('update/<str:pk>/',updatePatient, name='update'),

    path('getrdv/<str:pk>/',getrdv, name='getrdv'),
    path('addrdv/<str:pk>/',AddRdv, name='addrdv'),
    path('drrdv/<str:did>/',DailyIncome, name='drrdv'),
    path('weekincome/<str:did>/',WeeklyIncome, name='weekincome'),
    path('monthincome/<str:did>/',MonthIncome, name='monthincome'),
    path('yearincome/<str:did>/',YearIncome, name='yearincome'),
    path('search/',search, name='search'),
    path('drsearch/',drsearch, name='drsearch'),
    path('drreg/', doctor_register.as_view(), name='drreg'),
    path('assreg/', assistant_register.as_view(), name='assreg'),
    path('loginmed/', login_request, name='loginmed'),
    path('logirec/', login_rec, name='loginrec'),
    path('Drs/', Doctors, name='Drs'),
    path('reg/', registerUser, name='reg'),
    path('deletedr/<str:pk>/', deleteDoctor, name='deletedr'),
    path('addadmin/', addadmin, name='addadmin'),
    path('addfood/', Addfood, name='addfood'),
    path('addused/', AddUsed, name='addused'),
    path('addmed/', AddMed, name='addmed'),
    path('medecines/', Medecines, name='medecines'),
    path('medecines/', Food, name='medecines'),
    path('used/', Used, name='used'),
    path('allrdvs/', Allrdvs, name='allrdvs'),
    path('monthtotal/', MonthTotal, name='monthtotal'),
    path('weektotal/', WeekTotal, name='weektotal'),
    path('calendar/',  CalendarView.as_view(), name='calendar'),
    path('yt/',  YearTotal, name='yt'),
    path('ts/',  AddTime, name='ts'),
    path('tsd/',  TimeSlotDoctor, name='tsd'),
    path('tsa/',  TimeSlotAssistsnt, name='tsa'),
    path('deletets/<str:pk>/',  deletets, name='deletets'),
    path('istrue/<str:p>',  isinn, name='istrue'),
    path('istruets/<str:p>',  isinnts, name='istruets'),
    path('ist/<str:p>',  isinnop, name='ist'),
    path('istt/<str:p>',  isinntout, name='istt'),
    path('patdet/<str:p>',  PatientDetails, name='patdet'),
    path('apo',  AjoutPatOp, name='apo'),
    path('pd',  PatientsOfDoctor, name='pd'),
    path('rr',  reciptionist_register.as_view(), name='rr'),
    path('dass',  draddass.as_view(), name='dass'),
    path('dd',  DailyDr, name='dd'),
    path('md',  MonthDr, name='md'),
    path('wd',  WeeklyDr, name='wd'),
    path('yd',  YearDr, name='yd'),
    path('assistants',  Assistants, name='assistants'),
    path('chemin',  chemin, name='chemin'),
    path('floor',  floor, name='floor'),
    path('op',  op, name='op'),
    path('rb/<str:p>',  removeBed, name='rb'),
    path('draddpat',  draddpat, name='draddpat'),
    path('dapo',  DrAjoutPatOp, name='dapo'),


    #path("calendars/", CalendarViewNew.as_view(), name="calendars"),
    #path("calendar/", CalendarView.as_view(), name="calendar"),
    #path("event/new/", create_event, name="event_new"),
    #path("event/edit/<int:pk>/", EventEdit.as_view(), name="event_edit"),



   # path("all-event-list/", AllEventsListView.as_view(), name="all_events"),
   # path(   "running-event-list/",  RunningEventsListView.as_view(),  name="running_events",  ),



]



# Generated by Django 4.0.1 on 2022-02-10 21:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0010_user_age'),
    ]

    operations = [
        migrations.AddField(
            model_name='dctr',
            name='prc',
            field=models.CharField(default='', max_length=25),
        ),
        migrations.AddField(
            model_name='dctr',
            name='prccherg',
            field=models.CharField(default='', max_length=25),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-07 18:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0002_used_alter_rdv_prixprop'),
    ]

    operations = [
        migrations.AddField(
            model_name='patient',
            name='isop',
            field=models.BooleanField(default=False),
        ),
    ]





import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="med",
    version="v0.0.1",

    author="Maggie",
    author_email="bechmanel@gmail.com",
    description="Django project",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mag1i/med.git",
    project_urls={
        "Bug Tracker": "https://github.com/mag1i/med.git/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "."},
    packages=setuptools.find_packages(where="."),
    python_requires=">=3.9",
    scripts=["manage.py"],
)


# Generated by Django 4.0.1 on 2022-02-07 13:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Used',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=25)),
                ('type', models.CharField(default='', max_length=25)),
                ('quantity', models.IntegerField(default=1)),
                ('prix', models.FloatField(default=0)),
                ('total', models.FloatField(default=0)),
            ],
        ),
        migrations.AlterField(
            model_name='rdv',
            name='prixprop',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=8),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-09 22:33

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0004_remove_rdv_nature_remove_rdv_prixprop_patient_nature_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Rec',
            fields=[
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.RemoveField(
            model_name='assistant',
            name='role',
        ),
        migrations.AddField(
            model_name='user',
            name='is_receptionist',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='patient',
            name='casp',
            field=models.CharField(default='', max_length=15),
        ),
        migrations.AlterField(
            model_name='patient',
            name='cast',
            field=models.CharField(default='', max_length=15),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-14 17:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0013_food_dt_medecines_dt_used_dt'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patient',
            name='currentstate',
            field=models.CharField(default='', max_length=15),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-10 21:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0009_remove_user_age'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='age',
            field=models.IntegerField(default=0),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-07 21:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0003_patient_isop'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rdv',
            name='nature',
        ),
        migrations.RemoveField(
            model_name='rdv',
            name='prixprop',
        ),
        migrations.AddField(
            model_name='patient',
            name='nature',
            field=models.CharField(default='', max_length=20),
        ),
        migrations.AddField(
            model_name='patient',
            name='prixprop',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=8),
        ),
    ]



# Generated by Django 4.0.1 on 2022-02-09 23:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0006_assistant_doctor_assistant_dr'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='assistant',
            name='doctor',
        ),
        migrations.RemoveField(
            model_name='assistant',
            name='dr',
        ),
        migrations.RemoveField(
            model_name='assistant',
            name='drid',
        ),
        migrations.AddField(
            model_name='assistant',
            name='drid',
            field=models.ManyToManyField(to='med.Dctr'),
        ),
    ]



"""
Django settings for medapp project.

Generated by 'django-admin startproject' using Django 4.0.1.

For more information on this file, see
https://docs.djangoproject.com/en/4.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.0/ref/settings/
"""
import os
from pathlib import Path
from django.conf import settings
# Build paths inside the project like this: BASE_DIR / 'subdir'.
import med

BASE_DIR = Path(__file__).resolve().parent.parent
ROOT_PATH = os.path.dirname(__file__)




# Django settings for project.

PROJECT_DIR = os.path.dirname(__file__)
# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
#SECRET_KEY = 'django-insecure-_iseerk=h)$0n^9v(2y24b=h&c*$bea-5ba7qyt!qgvt1&%sxo'
SECRET_KEY =  os.environ.get('DJANGO_SECRET_KEY', 'cg#p$g+j9tax!#a3cup@1$8obt2_+&k3q+pmu)5%asj6yjpkag')

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG =  os.environ.get('DJANGO_DEBUG', '') != 'False'

ALLOWED_HOSTS = []

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'widget_tweaks',
    'med',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'medapp.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'medapp.wsgi.application'

# Database
# https://docs.djangoproject.com/en/4.0/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': BASE_DIR / 'db.sqlite3',
    }
}


# Password validation
# https://docs.djangoproject.com/en/4.0/ref/settings/#auth-password-validators
AUTH_PASSWORD_VALIDATORS = []

'''''
AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]
'''
AUTH_USER_MODEL = 'med.User'


# Internationalization
# https://docs.djangoproject.com/en/4.0/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.0/howto/static-files/
SITE_ROOT = os.path.dirname(os.path.realpath(__file__))
'''''
STATIC_URL = '/static/'
STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static')]
VENV_PATH = os.path.dirname(BASE_DIR)
STATIC_ROOT = os.path.join(VENV_PATH, 'static_root')
'''''
STATIFILE_DIRS = [
    os.path.join(BASE_DIR, 'static'),
]

STATIC_URL = '/static/'

STATIC_ROOT = os.path.join(BASE_DIR, 'static/images')
# Default primary key field type
# https://docs.djangoproject.com/en/4.0/ref/settings/#default-auto-field
DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'



from datetime import datetime, date

from django.contrib.auth import get_user_model
from django.db import models
from django.contrib.auth.models import User, AbstractUser


# Create your models here.
from django.urls import reverse
from django.utils import timezone
from django.utils.timezone import now



class User(AbstractUser):

    is_doctor = models.BooleanField(default=False)
    is_admin = models.BooleanField(default=True)
    is_assistant = models.BooleanField(default=False)
    is_receptionist = models.BooleanField(default=False)

    fn = models.CharField(max_length=25, default='')
    ln = models.CharField(max_length=25, default='')
    age = models.IntegerField(default=0)
    phone = models.IntegerField(default=0)
    address = models.CharField(max_length=30, default='')


    def __str__(self):
        return self.fn + " " + self.ln

class Rec (models.Model):
    user = models.OneToOneField(User, on_delete = models.CASCADE, primary_key = True)

class Dctr (models.Model):
    user = models.OneToOneField(User, on_delete = models.CASCADE, primary_key = True)
    sector = models.CharField(max_length=30, default='')
    spec = models.CharField(max_length=25, default='')
    prc = models.CharField(max_length=25, default='')
    prccherg = models.CharField(max_length=25, default='')
    paymanet= models.FloatField(default=0)
    def __str__(self):
        return self.user.fn + " " + self.user.ln



class Assistant (models.Model):
    user = models.OneToOneField(User, on_delete = models.CASCADE, primary_key = True)
    drid=models.ManyToManyField(Dctr)



    def __str__(self):
        return self.user.fn + " " + self.user.ln

    def get_drid_ids(self):
        ret = ''

        for dept in self.drid.all():
            ret = dept.user.id
        # remove the last ',' and return the value.

        return ret

    def get_drid_values(self):
        ret = ''
        for dept in self.drid.all():
            ret = ret + dept.user.fn + '  ,'
        # remove the last ',' and return the value.
        return ret[:-1]




class Patient (models.Model):
    c = [
        ('Confirme', 'Confirme'),
        ('Non conf', 'Non conf'),
        ('Present', 'Present'),
        ('Absent', 'Absent')
    ]
    auto_increment_id = models.AutoField(primary_key=True)
    drid=models.ForeignKey(Dctr, on_delete=models.SET_NULL, null=True, blank=True)
    #rdv = models.ForeignKey(Event, on_delete=models.CASCADE, related_name="events")
    firstname = models.CharField(max_length=25, default='')
    lastname = models.CharField(max_length=25, default='')
    age_patient = models.IntegerField(default=0)
    phonep = models.IntegerField(default=0)
    addressp = models.CharField(max_length=30)
    currentstate=models.CharField(max_length=15, choices=c)

    casp=models.CharField(max_length=15, default='')
    cast=models.CharField(max_length=15, default='')
    isop= models.BooleanField(default=False)
    nature = models.CharField(max_length=20, default='')
    prixprop = models.DecimalField(blank=True, max_digits=8, decimal_places=2, default=0)
    prix = models.DecimalField(blank=True,max_digits=8, decimal_places=2, default=0)
    orient = models.CharField(blank=True, max_length=20, default='')
    bed=models.IntegerField(blank=True, default=0)
    isin=models.BooleanField(default=False)

    def __str__(self):
        return self.firstname + " " +self.lastname

class Rdv(models.Model):
    pp = models.ForeignKey(Patient, on_delete=models.CASCADE,  null=True, blank=True)
    dr = models.ForeignKey(Dctr, on_delete=models.CASCADE,  null=True, blank=True)

 #   user = models.ForeignKey(User, on_delete=models.CASCADE, related_name="events")
    title = models.CharField(max_length=200)
    description = models.TextField()
    paid= models.DecimalField ( max_digits = 8, decimal_places=2 )
    rdvtime = models.DateTimeField()
    hr=models.IntegerField()
    mn=models.CharField(max_length=2)



    def __str__(self):
        return self.title

class medecines (models.Model):
    name = models.CharField(max_length=25, default='')
    type = models.CharField(max_length=25, default='')
    quantity= models.IntegerField(default=1)
    prix=models.FloatField(default=0)
    total=models.FloatField(default=0)
    dt=models.DateField(auto_now_add=True, null=True, blank=True)

    def __str__(self):
        return self.name

class food (models.Model):
    name = models.CharField(max_length=25, default='')
    type = models.CharField(max_length=25, default='')
    quantity= models.IntegerField(default=1)
    prix = models.FloatField(default=0)
    total = models.FloatField(default=0)
    dt=models.DateField(auto_now_add=True)

    def __str__(self):
        return self.name
class Used (models.Model):
    name = models.CharField(max_length=25, default='')
    type = models.CharField(max_length=25, default='')
    quantity= models.IntegerField(default=1)
    prix = models.FloatField(default=0)
    total = models.FloatField(default=0)
    dt=models.DateField(auto_now_add=True)


    def __str__(self):
        return self.name

class TimeSlot (models.Model):
    h=models.IntegerField()
    m=models.CharField(max_length=2)

"""""
    #event = models.ForeignKey(Event, on_delete=models.CASCADE, related_name="events")
    user = models.ForeignKey(
        User, on_delete=models.CASCADE, related_name="event_members"
    )

  #  class Meta:        unique_together = ["event", "user"]

    def __str__(self):
        return str(self.user)
    """""